Training
========

STonKGs pre-training
--------------------

.. automodule:: stonkgs.models.stonkgs_pretraining
   :members:

STonKGs fine-tuning
-------------------

.. automodule:: stonkgs.models.stonkgs_finetuning
   :members:
